@@ -1,5 +1,4 @@
 """Use this module to create an IMPHTTAB for an instrument."""
-from __future__ import absolute_import, print_function, division
 
 # STDLIB
 import os
@@ -18,13 +17,13 @@ from astropy.io import fits
 from . import graphfile as sgf
 
 __all__ = ['create_table', 'create_nicmos_table', 'create_table_from_table']
-__version__ = '0.5.1'
-__vdate__ = '02-Aug-2016'
+__version__ = '0.6'
+__vdate__ = '04-Mar-2020'
 
 
 def compute_values(obsmode, component_dict):
     """Compute the 3 basic photometric values needed for a given
-    observation mode string using `pysynphot`.
+    observation mode string using ``stsynphot``.
 
     Values calculated:
 
@@ -47,53 +46,20 @@ def compute_values(obsmode, component_dict):
         Dictionary with photometry keywords as keys.
 
     """
-    import pysynphot as S
+    import stsynphot as stsyn
 
     # Define the bandpass for this obsmode
-    bp = S.ObsBandpass(obsmode, component_dict=component_dict)
+    bp = stsyn.band(obsmode, component_dict=component_dict)
 
     # compute the photometric values
-    uresp = bp.unit_response()
+    uresp = bp.unit_response(bp.area).value
+    pivot = bp.pivot().value
+    photbw = bp.photbw().value
+
     if not np.isfinite(uresp):
         uresp = 0.0
 
-    return {'PHOTFLAM': uresp, 'PHOTPLAM': bp.pivot(), 'PHOTBW': bp.photbw()}
-
-
-def compute_synphot_values(obsmode):
-    """Calculate the same values as :func:`compute_values` but
-    using IRAF SYNPHOT.
-
-    .. note::
-
-        This is replaced by :func:`compute_values` but kept for debugging.
-
-    Parameters
-    ----------
-    obsmode : str
-        Observation mode for which to calculate values.
-
-    Returns
-    -------
-    valdict : dict
-        Dictionary with photometry keywords as keys.
-
-    """
-    from pyraf import iraf  # noqa
-    from iraf import stsdas, hst_calib, synphot  # noqa
-
-    tmpfits = os.path.join(tempfile.gettempdir(), 'temp.fits')
-    synphot.bandpar(obsmode, output=tmpfits, Stdout=1)
-
-    with fits.open(tmpfits) as f:
-        d = f[1].data
-        photflam = d['uresp'][0]
-        pivot = d['pivwv'][0]
-        rmswidth = d['bandw'][0]
-
-    os.remove(tmpfits)
-
-    return {'PHOTFLAM': photflam, 'PHOTPLAM': pivot, 'PHOTBW': rmswidth}
+    return {'PHOTFLAM': uresp, 'PHOTPLAM': pivot, 'PHOTBW': photbw}
 
 
 def expand_obsmodes(basemode, pardict):
@@ -122,12 +88,11 @@ def expand_obsmodes(basemode, pardict):
 
     """
     basemode = basemode.lower()
-    # obsmode_str = '%s,%s#%0.4f'
     olist = list()
 
     if len(pardict) > 0:
         for k in pardict.keys():
-            basemode = basemode.replace('{0},'.format(k), '')
+            basemode = basemode.replace(f'{k},', '')
 
     # we don't have any parameterized variables, so just return the basemode
     if len(pardict) == 0:
@@ -173,6 +138,7 @@ def interpret_obsmode(obsmode):
 
     Examples
     --------
+    >>> from reftools.mkimphttab import interpret_obsmode
     >>> interpret_obsmode('acs,wfc1,mjd#52334.0000,fr853n#8158.0000')
     'acs,wfc1,mjd#,fr853n#'
 
@@ -254,15 +220,14 @@ def make_pri_hdu(filename, numpars, instrument, detector, pedigree, useafter):
         Useafter date in the format of ``MMM DD YYYY HH:MM:SS``.
 
     """
-    import pysynphot as S
-    from pysynphot import refs
+    import stsynphot as stsyn
 
-    d = refs.getref()
+    d = stsyn.getref()
     phdu = fits.PrimaryHDU()
 
     phdu.header['DATE'] = (get_date(), 'Date FITS file was generated')
     phdu.header['ORIGIN'] = ('astropy-fits',
-                             'astropy version {0}'.format(astropy.__version__))
+                             f'astropy version {astropy.__version__}')
     phdu.header['FILENAME'] = (filename, 'Name of file')
     phdu.header['FILETYPE'] = ('Image photometry table', 'File type')
     phdu.header['NEXTEND'] = (3, 'Number of extensions in file')
@@ -271,7 +236,7 @@ def make_pri_hdu(filename, numpars, instrument, detector, pedigree, useafter):
     phdu.header['DBTABLE'] = ('IMPHTTAB', 'Database table')
     phdu.header['INSTRUME'] = (instrument, 'Instrument name')
     phdu.header['DETECTOR'] = (detector, 'Detector name')
-    phdu.header['SYNSWVER'] = (S.__version__,
+    phdu.header['SYNSWVER'] = (stsyn.__version__,
                                'Version of synthetic photometry software')
     phdu.header['MKTABVER'] = (__version__, 'Version of reftools.mkimphttab')
     phdu.header['GRAPHTAB'] = (os.path.basename(d['graphtable']),
@@ -355,8 +320,12 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
 
 
     """
-    import pysynphot as S
-    from pysynphot import refs
+    import stsynphot as stsyn
+    from stsynphot import conf as stsyn_conf
+
+    synname = 'stsynphot'
+    synver = stsyn.__version__
+    d = stsyn.getref()
 
     if not output.endswith('_imp.fits'):
         output = output + '_imp.fits'
@@ -368,13 +337,15 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
 
     # Define graph and component tables.
     if tmgtab is None:
-        tmgtab = refs.GRAPHTABLE
+        tmgtab = d['graphtable']
     if tmctab is None:
-        tmctab = refs.COMPTABLE
+        tmctab = d['comptable']
     if tmttab is None:
-        tmttab = refs.THERMTABLE
+        tmttab = d['thermtable']
 
-    refs.setref(graphtable=tmgtab, comptable=tmctab, thermtable=tmttab)
+    stsyn_conf.graphtable = tmgtab
+    stsyn_conf.comptable = tmctab
+    stsyn_conf.thermtable = tmttab
     x = sgf.read_graphtable(tmgtab, tmctab, tmttab)
 
     if len(mode_list) == 0:
@@ -407,7 +378,7 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
         npars = len(fpars)
         npar_vals.append(npars)
         fpars_vals.append(fpars)
-        fpars_len = [len(f) for f in fpars]
+        fpars_len = list(map(len, fpars))
 
         if len(fpars_len) == 0:
             fpars_max = 0
@@ -431,7 +402,7 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
     #
     # Start by determining the maximum num of parameters in any given obsmode
     max_npars = np.array(npar_vals, np.int32).max()
-    log.info('MAX_NPARS: {0}   NROWS: {1}'.format(max_npars, nrows))
+    log.info(f'MAX_NPARS: {max_npars}   NROWS: {nrows}')
 
     # Now, define empty lists for NELEM* and PAR*VALUES columns
     #
@@ -489,20 +460,19 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
     nmode_vals = list()
 
     # dictionary to hold optical components
-    # (pysynphot.observationmode._Component objects)
     component_dict = {}
 
     # list to hold skipped obsmodes
     skipped_obs = []
 
     if verbose:
-        log.info('Computing photmetry values for each row\'s obsmode...')
+        log.info("Computing photmetry values for each row's obsmode...")
         sys.stdout.flush()
 
     for nr in range(nrows):
         # Provide some indication of which row is being worked
         if verbose:
-            log.info('Row: {0}'.format(nr + 1))
+            log.info(f'Row: {nr + 1}')
             sys.stdout.flush()
 
         obsmode = obsmodes[nr]
@@ -524,7 +494,7 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
         # If there are warnings from here, try updating rules_dict
         # in graphtab.py
         if nmodes == 0 and verbose:
-            log.warn('No info for {0}'.format(obsmode))
+            log.warning(f'No info for {obsmode}')
 
         pflam = np.zeros(nmodes, np.float64)
         pplam = np.zeros(nmodes, np.float64)
@@ -536,7 +506,7 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
             try:
                 value = compute_values(fullmode, component_dict)
             except ValueError as e:
-                if e.message == 'Integrated flux is <= 0':
+                if 'Integrated flux is <= 0' in str(e):
                     # integrated flux is zero, skip this obsmode
                     skip = True
                     skipped_obs.append(obsmode)
@@ -549,15 +519,15 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
                     parnames_rows = np.delete(parnames_rows, nr, 0)
 
                     if verbose:
-                        log.info('\tSkipping {0}'.format(obsmode))
+                        log.info(f'\tSkipping {obsmode}')
 
                     break
-                elif e.message == 'math domain error':
+                elif 'math domain error' in str(e):
                     skip = True
                     skipped_obs.append(obsmode)
 
                     if verbose:
-                        log.info('\tSkipping {0}'.format(obsmode))
+                        log.info(f'\tSkipping {obsmode}')
 
                     flam_datacol_vals.pop(nr)
                     plam_datacol_vals.pop(nr)
@@ -571,8 +541,7 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
                     raise
 
             if verbose:
-                log.info('\tPHOTFLAM({0}) = {1}'.format(
-                        fullmode, value['PHOTFLAM']))
+                log.info(f"\tPHOTFLAM({fullmode}) = {value['PHOTFLAM']}")
 
             pflam[n] = value['PHOTFLAM']
             pplam[n] = value['PHOTPLAM']
@@ -659,10 +628,9 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
         bw_cols.append(bvals)
 
     ped_vals = [fits.getval(tmctab, 'pedigree', 0)] * len(nmode_vals)
-    descrip_str = (
-        'Generated {0} from {1}, mkimphttab version {2}, '
-        'pysynphot version {3}'.format(
-            get_date(), os.path.basename(tmgtab), __version__, S.__version__))
+    descrip_str = (f'Generated {get_date()} from {os.path.basename(tmgtab)}, '
+                   f'mkimphttab version {__version__}, '
+                   f'{synname} version {synver}')
     descrip_vals = [descrip_str] * len(nmode_vals)
 
     # Finally, create structures needed to define this row in the FITS table
@@ -684,19 +652,19 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
     parvals_tabcols = list()
     nelem_tabcols = list()
     parnames_tabcols = list()
-    parnames_format = str(fpars_sz) + "A"
+    parnames_format = str(fpars_sz) + 'A'
 
     # for each parameterized element, create a set of columns specifying the
     # range of values for that parameter and the number of elements covering
     # that range namely, the PAR<n>VALUES and NELEM<n> columns
     for p in range(max_npars):
+        pp1 = p + 1
         nelem_tabcols.append(fits.Column(
-            name="NELEM"+str(p+1), format="I", array=nelem_cols[p]))
+            name=f'NELEM{pp1}', format='I', array=nelem_cols[p]))
         parvals_tabcols.append(fits.Column(
-            name="PAR"+str(p+1)+"VALUES", format="PD()",
-            array=parvals_cols[p]))
+            name=f'PAR{pp1}VALUES', format="PD()", array=parvals_cols[p]))
         parnames_tabcols.append(fits.Column(
-            name="PAR"+str(p+1)+"NAMES", format=parnames_format,
+            name=f'PAR{pp1}NAMES', format=parnames_format,
             array=parnames_cols[p]))
 
     # create the set of results columns
@@ -718,14 +686,14 @@ def create_table(output, basemode, detector, useafter, tmgtab=None,
             bcols = bw_cols[p]
 
         flam_tabcols.append(fits.Column(
-            name='PHOTFLAM'+pstr, format=format_str, array=fcols))
+            name=f'PHOTFLAM{pstr}', format=format_str, array=fcols))
         plam_tabcols.append(fits.Column(
-            name='PHOTPLAM'+pstr, format=format_str, array=pcols))
+            name=f'PHOTPLAM{pstr}', format=format_str, array=pcols))
         bw_tabcols.append(fits.Column(
-            name='PHOTBW'+pstr, format=format_str, array=bcols))
+            name=f'PHOTBW{pstr}', format=format_str, array=bcols))
 
     # Now create the FITS file with the table in each extension
-    log.info('Creating full table: {0}'.format(output))
+    log.info(f'Creating full table: {output}')
 
     phdu = make_pri_hdu(output, max_npars, basemode.split(',')[0], detector,
                         ped_vals[0], useafter)
@@ -819,7 +787,7 @@ def create_table_from_table(output, useafter, imphttab, **kwargs):
     # if there are more than 3 extensions assume they are static and
     # append them to the output file
     if extra_exten:
-        junkfile = tempfile.NamedTemporaryFile(dir='./', delete=False)
+        junkfile = tempfile.NamedTemporaryFile(dir=os.curdir, delete=False)
         print("Adding static extensions to output", extra_exten)
         with fits.open(imphttab) as imp:
             with fits.open(output) as outfile:
